@@ -9,6 +9,7 @@ from . import water_balance
 from . import spatial_validation
 from . import ensembles
 
-__author__ = """Jannis M. Hoch"""
+__author__ = """Jannis M. Hoch, Niko Wanders"""
+__institute__= """Utrecht University"""
 __email__ = 'j.m.hoch@uu.nl'
-__version__ = '0.2.3'
+__version__ = '0.2.5'
